==> buildpack-client-0.0.6-sources.jar: dev/snowdrop/buildpack/docker/StreamContentFluentImpl.java <==
package dev.snowdrop.buildpack.docker;

import dev.snowdrop.buildpack.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
public class StreamContentFluentImpl<A extends dev.snowdrop.buildpack.docker.StreamContentFluent<A>> extends dev.snowdrop.buildpack.builder.BaseFluent<A> implements dev.snowdrop.buildpack.docker.StreamContentFluent<A>{
  public StreamContentFluentImpl() {
  }
  public StreamContentFluentImpl(dev.snowdrop.buildpack.docker.StreamContent instance) {
  }
  private java.lang.String path;
  private java.lang.Long size;
  private dev.snowdrop.buildpack.docker.ContainerEntry.DataSupplier dataSupplier;
  public java.lang.String getPath() {
    return this.path;
  }
  public A withPath(java.lang.String path) {
    this.path=path; return (A) this;
  }
  public java.lang.Boolean hasPath() {
    return this.path != null;
  }
  public java.lang.Long getSize() {
    return this.size;
  }
  public A withSize(java.lang.Long size) {
    this.size=size; return (A) this;
  }
  public java.lang.Boolean hasSize() {
    return this.size != null;
  }
  public dev.snowdrop.buildpack.docker.ContainerEntry.DataSupplier getDataSupplier() {
    return this.dataSupplier;
  }
  public A withDataSupplier(dev.snowdrop.buildpack.docker.ContainerEntry.DataSupplier dataSupplier) {
    this.dataSupplier=dataSupplier; return (A) this;
  }
  public java.lang.Boolean hasDataSupplier() {
    return this.dataSupplier != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StreamContentFluentImpl that = (StreamContentFluentImpl) o;
    if (path != null ? !path.equals(that.path) :that.path != null) return false;
    if (size != null ? !size.equals(that.size) :that.size != null) return false;
    if (dataSupplier != null ? !dataSupplier.equals(that.dataSupplier) :that.dataSupplier != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(path,  size,  dataSupplier,  super.hashCode());
  }
  
}

==> buildpack-client-0.0.12-sources.jar: dev/snowdrop/buildpack/docker/StreamContentFluentImpl.java <==
package dev.snowdrop.buildpack.docker;

import java.lang.Integer;
import dev.snowdrop.buildpack.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
public class StreamContentFluentImpl<A extends dev.snowdrop.buildpack.docker.StreamContentFluent<A>> extends dev.snowdrop.buildpack.builder.BaseFluent<A> implements dev.snowdrop.buildpack.docker.StreamContentFluent<A>{
  public StreamContentFluentImpl() {
  }
  public StreamContentFluentImpl(dev.snowdrop.buildpack.docker.StreamContent instance) {
  }
  private java.lang.String path;
  private java.lang.Long size;
  private java.lang.Integer mode;
  private dev.snowdrop.buildpack.docker.ContainerEntry.DataSupplier dataSupplier;
  public java.lang.String getPath() {
    return this.path;
  }
  public A withPath(java.lang.String path) {
    this.path=path; return (A) this;
  }
  public java.lang.Boolean hasPath() {
    return this.path != null;
  }
  public java.lang.Long getSize() {
    return this.size;
  }
  public A withSize(java.lang.Long size) {
    this.size=size; return (A) this;
  }
  public java.lang.Boolean hasSize() {
    return this.size != null;
  }
  public java.lang.Integer getMode() {
    return this.mode;
  }
  public A withMode(java.lang.Integer mode) {
    this.mode=mode; return (A) this;
  }
  public java.lang.Boolean hasMode() {
    return this.mode != null;
  }
  public dev.snowdrop.buildpack.docker.ContainerEntry.DataSupplier getDataSupplier() {
    return this.dataSupplier;
  }
  public A withDataSupplier(dev.snowdrop.buildpack.docker.ContainerEntry.DataSupplier dataSupplier) {
    this.dataSupplier=dataSupplier; return (A) this;
  }
  public java.lang.Boolean hasDataSupplier() {
    return this.dataSupplier != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StreamContentFluentImpl that = (StreamContentFluentImpl) o;
    if (path != null ? !path.equals(that.path) :that.path != null) return false;
    if (size != null ? !size.equals(that.size) :that.size != null) return false;
    if (mode != null ? !mode.equals(that.mode) :that.mode != null) return false;
    if (dataSupplier != null ? !dataSupplier.equals(that.dataSupplier) :that.dataSupplier != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(path,  size,  mode,  dataSupplier,  super.hashCode());
  }
  
}
